==> jei-1.20.1-fabric-15.20.0.129-sources.jar: mezz/jei/fabric/platform/RenderHelper.java <==
package mezz.jei.fabric.platform;

import com.mojang.datafixers.util.Either;
import mezz.jei.api.constants.ModIds;
import mezz.jei.common.platform.IPlatformRenderHelper;
import mezz.jei.library.util.ResourceLocationUtil;
import net.minecraft.class_1011;
import net.minecraft.class_1058;
import net.minecraft.class_1087;
import net.minecraft.class_1293;
import net.minecraft.class_1799;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_325;
import net.minecraft.class_327;
import net.minecraft.class_332;
import net.minecraft.class_5348;
import net.minecraft.class_5632;
import net.minecraft.class_5684;
import net.minecraft.class_6862;
import net.minecraft.class_7764;
import net.minecraft.class_8001;
import java.util.ArrayList;
import java.util.List;
import java.util.Optional;
import java.util.stream.Collectors;
import java.util.stream.Stream;

public class RenderHelper implements IPlatformRenderHelper {
	@Override
	public class_327 getFontRenderer(class_310 minecraft, class_1799 itemStack) {
		return minecraft.field_1772;
	}

	@Override
	public boolean shouldRender(class_1293 potionEffect) {
		return true;
	}

	@Override
	public class_1058 getParticleIcon(class_1087 bakedModel) {
		return bakedModel.method_4711();
	}

	@Override
	public class_325 getItemColors() {
		class_310 minecraft = class_310.method_1551();
		return minecraft.field_1760;
	}

	@Override
	public Optional<class_1011> getMainImage(class_1058 sprite) {
		class_7764 contents = sprite.method_45851();
		class_1011[] frames = contents.field_40540;
		if (frames.length == 0) {
			return Optional.empty();
		}
		class_1011 frame = frames[0];
		return Optional.ofNullable(frame);
	}

	@Override
	public void renderTooltip(class_332 guiGraphics, List<Either<class_5348, class_5632>> elements, int x, int y, class_327 font, class_1799 stack) {
		List<class_5684> components = elements.stream()
			.flatMap(e -> e.map(
				text -> font.method_1728(text, 400).stream().map(class_5684::method_32662),
				tooltipComponent -> Stream.of(createClientTooltipComponent(tooltipComponent))
			))
			.collect(Collectors.toCollection(ArrayList::new));

		guiGraphics.method_51435(font, components, x, y, class_8001.field_41687);
	}

	@Override
	public class_2561 getName(class_6862<?> tagKey) {
		String tagTranslationKey = getTagTranslationKey(tagKey);
		return class_2561.method_48321(tagTranslationKey, "#" + tagKey.comp_327());
	}

	private static String getTagTranslationKey(class_6862<?> tagKey) {
		StringBuilder stringBuilder = new StringBuilder();
		stringBuilder.append("tag.");
		class_2960 registryIdentifier = tagKey.comp_326().method_29177();
		class_2960 tagIdentifier = tagKey.comp_327();
		if (!registryIdentifier.method_12836().equals(ModIds.MINECRAFT_ID)) {
			stringBuilder.append(registryIdentifier.method_12836()).append(".");
		}

		String registryId = ResourceLocationUtil.sanitizePath(registryIdentifier.method_12832());
		String tagId = ResourceLocationUtil.sanitizePath(tagIdentifier.method_12832());

		stringBuilder.append(registryId)
			.append(".")
			.append(tagIdentifier.method_12836())
			.append(".")
			.append(tagId);
		return stringBuilder.toString();
	}

	private class_5684 createClientTooltipComponent(class_5632 tooltipComponent) {
		if (tooltipComponent instanceof class_5684 clientTooltipComponent) {
			return clientTooltipComponent;
		}
		return class_5684.method_32663(tooltipComponent);
	}

	@Override
	public class_1087 createLimitedQuadItemModel(class_1087 bakedModel) {
		return FabricLimitedQuadItemModel.wrap(bakedModel);
	}
}

==> jei-1.21.1-fabric-19.27.0.340-sources.jar: mezz/jei/fabric/platform/RenderHelper.java <==
package mezz.jei.fabric.platform;

import com.mojang.datafixers.util.Either;
import mezz.jei.common.platform.IPlatformRenderHelper;
import net.minecraft.class_1011;
import net.minecraft.class_1058;
import net.minecraft.class_1087;
import net.minecraft.class_1293;
import net.minecraft.class_1799;
import net.minecraft.class_2561;
import net.minecraft.class_310;
import net.minecraft.class_325;
import net.minecraft.class_327;
import net.minecraft.class_332;
import net.minecraft.class_5348;
import net.minecraft.class_5632;
import net.minecraft.class_5684;
import net.minecraft.class_6862;
import net.minecraft.class_7764;
import net.minecraft.class_8001;
import java.util.ArrayList;
import java.util.List;
import java.util.Optional;
import java.util.stream.Collectors;
import java.util.stream.Stream;

public class RenderHelper implements IPlatformRenderHelper {
	@Override
	public class_327 getFontRenderer(class_310 minecraft, class_1799 itemStack) {
		return minecraft.field_1772;
	}

	@Override
	public boolean shouldRender(class_1293 potionEffect) {
		return true;
	}

	@Override
	public class_1058 getParticleIcon(class_1087 bakedModel) {
		return bakedModel.method_4711();
	}

	@Override
	public class_325 getItemColors() {
		class_310 minecraft = class_310.method_1551();
		return minecraft.field_1760;
	}

	@Override
	public Optional<class_1011> getMainImage(class_1058 sprite) {
		class_7764 contents = sprite.method_45851();
		class_1011[] frames = contents.field_40540;
		if (frames.length == 0) {
			return Optional.empty();
		}
		class_1011 frame = frames[0];
		return Optional.ofNullable(frame);
	}

	@Override
	public void renderTooltip(class_332 guiGraphics, List<Either<class_5348, class_5632>> elements, int x, int y, class_327 font, class_1799 stack) {
		List<class_5684> components = elements.stream()
			.flatMap(e -> e.map(
				text -> font.method_1728(text, 400).stream().map(class_5684::method_32662),
				tooltipComponent -> Stream.of(createClientTooltipComponent(tooltipComponent))
			))
			.collect(Collectors.toCollection(ArrayList::new));

		guiGraphics.method_51435(font, components, x, y, class_8001.field_41687);
	}

	@Override
	public class_2561 getName(class_6862<?> tagKey) {
		return tagKey.getName();
	}

	private class_5684 createClientTooltipComponent(class_5632 tooltipComponent) {
		if (tooltipComponent instanceof class_5684 clientTooltipComponent) {
			return clientTooltipComponent;
		}
		return class_5684.method_32663(tooltipComponent);
	}

	@Override
	public class_1087 createLimitedQuadItemModel(class_1087 bakedModel) {
		return FabricLimitedQuadItemModel.wrap(bakedModel);
	}
}
